"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LinkedEditiRangesProvider = void 0;
const tsyringe_1 = require("tsyringe");
const vscode_languageserver_1 = require("vscode-languageserver");
const vscode_uri_1 = require("vscode-uri");
const positionUtil_1 = require("../positionUtil");
const elmWorkspaceMatcher_1 = require("../util/elmWorkspaceMatcher");
const treeUtils_1 = require("../util/treeUtils");
class LinkedEditiRangesProvider {
    constructor() {
        this.provideLinkedEditingRanges = (params) => {
            var _a, _b, _c;
            const ranges = [];
            const nodeAtPostion = treeUtils_1.TreeUtils.getNamedDescendantForPosition(params.sourceFile.tree.rootNode, params.position);
            const range = {
                start: positionUtil_1.PositionUtil.FROM_TS_POSITION(nodeAtPostion.startPosition).toVSPosition(),
                end: positionUtil_1.PositionUtil.FROM_TS_POSITION(nodeAtPostion.endPosition).toVSPosition(),
            };
            if (((_a = nodeAtPostion.parent) === null || _a === void 0 ? void 0 : _a.type) === "function_declaration_left" &&
                treeUtils_1.TreeUtils.getTypeAnnotation((_b = nodeAtPostion.parent.parent) !== null && _b !== void 0 ? _b : undefined)) {
                ranges.push(this.addLinesToRange(range, -1));
                ranges.push(range);
            }
            if (((_c = nodeAtPostion.parent) === null || _c === void 0 ? void 0 : _c.type) === "type_annotation" &&
                nodeAtPostion.type === "lower_case_identifier") {
                ranges.push(range);
                ranges.push(this.addLinesToRange(range, 1));
            }
            return { ranges };
        };
        this.connection = tsyringe_1.container.resolve("Connection");
        this.connection.onRequest(vscode_languageserver_1.LinkedEditingRangeRequest.type, new elmWorkspaceMatcher_1.ElmWorkspaceMatcher((params) => vscode_uri_1.URI.parse(params.textDocument.uri)).handle(this.provideLinkedEditingRanges.bind(this)));
    }
    addLinesToRange(range, linesToAdd) {
        return {
            start: {
                line: range.start.line + linesToAdd,
                character: range.start.character,
            },
            end: {
                line: range.end.line + linesToAdd,
                character: range.end.character,
            },
        };
    }
}
exports.LinkedEditiRangesProvider = LinkedEditiRangesProvider;
//# sourceMappingURL=linkedEditingRangesProvider.js.map